# Creating Snohomish peak flow statistics output in PeakFQ format using PFFREX package

require(remotes)
remotes::install_gitlab("StreamStats/flood-frequency/PFFREX",
                        host = "code.usgs.gov",
                        build_vignettes = TRUE)
require(PFFREX)
require(testthat)
require(dataRetrieval)
require(tidyverse)

# Make temporary directory for output files
sno_q_output <- file.path("C:", "Users", "lowm1477", "OneDrive - Washington State Executive Branch Agencies", "Documents", "sno_q" )
dir.create(sno_q_output)

# Change the incubation range to the whole water year
incubation_range_sno <- list(c(pop = 'va',           start = "1001", end = "0930"))
# Daily discharge at Snohomish near Monroe
require(EGRET)
site_number_sno <- 12150800
start_date <- "1963-02-01"
end_date <- "2020-12-31"
daily_sno <- readNWISDaily(site_number_sno,"00060",start_date,end_date)
# Calculate peak flow
sno_q_peak <- map_dfr(incubation_range_sno, function(r){
  daily_sno %>%
    mutate(monthday = format(Date, "%m%d"),
           pop = r['pop']) %>%
    filter(monthday <= r['start'] | monthday >= r['end']) %>%
    group_by(pop, waterYear) %>%
    summarize(Q_max = max(Q) * 35.31467)
})
sno_q <- pivot_wider(sno_q_peak,
                     names_from = pop,
                     names_prefix = 'peak_',
                     values_from = Q_max)
# Reformat data frame to match NWIS
sno_q$site_no <- 12150800
sno_q$peak_WY <- sno_q$waterYear
sno_q$waterYear <- NULL

# Pull NWIS data
testSites <- c("12150800") #Snohomish station

NWISdata <- readNWISpeak(testSites) #the flow in this data frame will be replaced with sno_q
NWISinfo <- readNWISsite(testSites) #station information

NWISdata$peak_va <- round(sno_q$peak_va[2:59], digits = 0) #replace max daily max Q with max daily mean Q
# Skipping 1963 because NWIS data starts at 1964

testWATSTORE <- file.path(sno_q_output, "sno_max_mean_q.txt")

writeWATSTORE(NWISdata, testWATSTORE, siteInfo=NWISinfo)


# Check flow statistics from Peak FQ software output
median_flow <- harpSNO::df_marss %>%
  filter(var == "q_peak") %>%
  pull(value) %>%
  median()

# Calculate exceedance probability for median flow - should be 0.5
lp3_stat <- smwrBase::ppearsonIII(
  q = log10(median_flow),
  mean =  4.7392, # logqmean
  sd =  0.1550, # logqsd
  skew = 0.214) # logqskew

# Calculate return interval - should be 2
1 / (1 - lp3_stat)
