steelhead_hab_w <- hab_run('winter_steelhead', 'Current', 'curr')
steelhead_hab_s <- hab_run('summer_steelhead', 'Current', 'curr')

steelhead_base <- lcm_assign_steelhead(steelhead_hab_w, steelhead_hab_s)


lcm_results <- steelhead_base %>%
  mutate(
    bay_surv_w = 0.05,
    bay_surv_s = 0.05
  )  %>%
  lcm_run("all")

fw_ages <- lcm_results %>%
  filter(
    year == 100,
    grepl("_spawn_", lifestage)) %>%
  mutate(
    fw_age = stringr::str_extract(lifestage, "(?<=age)\\d"),
    run = stringr::str_extract(lifestage, "(?<=spawn_)\\w+"),
  ) %>%
  group_by(fw_age, run) %>%
  summarize(n = sum(n), .groups = "keep") %>%
  group_by(run) %>%
  mutate(perc = n/sum(n)) %>%
  arrange(desc(run)) %>% # winters first
  cbind(target = c(
    0.1045, 0.7825, 0.1130, # winters
    0.0168, 0.7983, 0.1849))%>% # then summers
  mutate(
    sq_diff = (perc-target)^2
  )

fw_ages

lcm_results %>%
  filter(
    year == 100,
    lifestage %in% c(
      "total_run_summer", "total_run_winter",
      "smolts_summer", "smolts_winter")) %>%
  mutate(
    run = stringr::str_extract(lifestage, "(?<=_)[:alpha:]+$"),
    lifestage = stringr::str_extract(lifestage, "\\w+(?=_)")) %>%
  group_by(run, lifestage) %>%
  summarize(n = sum(n), .groups = "keep") %>%
  pivot_wider(names_from = lifestage, values_from = n) %>%
  arrange(desc(run)) %>%
  mutate(SAR = total_run/smolts)

calc_steelhead_sar_coefficient <- function(wbay, sbay){
  steelhead_base %>%
    mutate(
      bay_surv_w = wbay,
      bay_surv_s = sbay
    )  %>%
    lcm_run("all")%>%
    filter(
      year == 100,
      lifestage %in% c(
        "total_run_summer", "total_run_winter",
        "smolts_summer", "smolts_winter"
      )) %>%
    mutate(
      run = stringr::str_extract(lifestage, "(?<=_)[:alpha:]+$"),
      lifestage = stringr::str_extract(lifestage, "\\w+(?=_)")) %>%
    group_by(run, lifestage) %>%
    summarize(n = sum(n), .groups = "keep") %>%
    pivot_wider(names_from = lifestage, values_from = n) %>%
    arrange(desc(run)) %>%
    mutate(SAR = total_run/smolts) %>%
    select(SAR) %>%
    ungroup() %>%
    pivot_wider(names_from = run, values_from = SAR) %>%
    mutate(wbay = wbay, sbay = sbay,
           wratio = wbay/winter, sratio = sbay/summer)
}

calc_steelhead_sar_coefficient(0.05, 0.06)

t1<- expand_grid(w = seq(0.02,0.24, 0.02),
                 s = seq(0.02,0.24, 0.02)) %>%
  pmap_dfr(calc_steelhead_sar_coefficient)

wratio <- mean(t1$wratio)
sratio <- mean(t1$sratio)

get_steelhead_escapement <- function(SAR_w, SAR_s){
  steelhead_base %>%
    mutate(
      bay_surv_w = SAR_w*wratio,
      bay_surv_s = SAR_s*sratio
    )  %>%
    lcm_run() %>%
    filter(year == 100) %>%
    summarize(n = sum(n))%>%
    mutate(SAR_w = SAR_w, SAR_s = SAR_s)
}

get_steelhead_escapement(0.013,0.019)

steelhead_esc <- expand_grid(
  SAR_w = seq(0.01, 0.04, 0.001),
  SAR_s = seq(0.01, 0.04, 0.001)
) %>%
  pmap_dfr(get_steelhead_escapement)

esc_plot <- steelhead_esc %>%
  mutate(
    n_bin = cut(
      n,
      breaks = c(-Inf, 975, 2044, 2501, 2788, Inf),
      labels = c("Low","0-25th", "25-75th", "75-100th", "High"))) %>%
  ggplot()+
  geom_rect(
    aes(xmin = SAR_w - 0.0005,
        xmax = SAR_w + 0.0005,
        ymin = SAR_s - 0.0005,
        ymax = SAR_s + 0.0005,
        fill = n_bin),
    color = "gray90")+
  coord_equal()+
  scale_fill_manual(
    values = c("#FCFEFA", "#DCF1DD", "#7BCCC4","#A1D0E4", "#CEE1EE"))+
  scale_x_continuous(
    labels = scales::label_percent())+
  scale_y_continuous(labels = scales::label_percent())+
  cowplot::theme_cowplot()+
  theme(panel.grid.major = element_line(color = "gray80"),
        panel.grid.minor = element_line(color = "gray90"))+
  labs(fill = "Total Spawners", x = "Winter-Run SAR",
       y = "Summer-Run SAR",
       title = "Snohomish Steelhead")
esc_plot

ggsave(sprintf("ignore/results/SNO_steelhead_SARs_%s.png", Sys.Date()),
       width = 8, height = 4.5)


get_steelhead_props <- function(SAR_w, SAR_s){
  steelhead_base %>%
    mutate(
      bay_surv_w = SAR_w*wratio,
      bay_surv_s = SAR_s*sratio
    )  %>%
    lcm_run(c("spawners_summer", "spawners_winter")) %>%
    filter(year == 100) %>%
    group_by(lifestage) %>%
    summarize(n = sum(n), .groups = "keep") %>%
    pivot_wider(names_from = lifestage, values_from = n) %>%
    mutate(SAR_w = SAR_w, SAR_s = SAR_s)
}

steelhead_props <- expand_grid(
  SAR_w = seq(0.01, 0.04, 0.001),
  SAR_s = seq(0.01, 0.04, 0.001)
) %>%
  pmap_dfr(get_steelhead_props)

prop_plot<- steelhead_props %>%
  mutate(ratio = spawners_winter/(spawners_summer+spawners_winter)) %>%
  ggplot()+
  geom_rect(
    aes(xmin = SAR_w - 0.0005,
        xmax = SAR_w + 0.0005,
        ymin = SAR_s - 0.0005,
        ymax = SAR_s + 0.0005,
        fill = ratio),
    color = "gray90")+
  coord_equal()+
  scale_fill_fermenter(
    labels = scales::label_percent(),
    direction = 1,
    palette = 9)+
  scale_x_continuous(
    labels = scales::label_percent())+
  scale_y_continuous(labels = scales::label_percent())+
  cowplot::theme_cowplot()+
  theme(panel.grid.major = element_line(color = "gray80"),
        panel.grid.minor = element_line(color = "gray90"))+
  labs(fill = "% winter-run", x = "Winter-Run SAR",
       y = "Summer-Run SAR",
       title = "Snohomish Steelhead")

saveRDS(
  esc_plot,
  sprintf("ignore/results/SNO_steelhead_esc_%s.RDS", Sys.Date()))

saveRDS(
  prop_plot,
  sprintf("ignore/results/SNO_steelhead_props_%s.RDS", Sys.Date()))
