library(tidyverse)
load_all()


hab_base_coho <- hab_run("coho", "Current", "curr") %>%
  lcm_assign()

modify_bay_coho <- function(new_surv){
  hab_base_coho %>%
    mutate(bay = new_surv) %>%
    lcm_run("all") %>%
    filter(
      year == 100,
      lifestage %in% c("spawners", "total_run", "smolts")
    ) %>%
    group_by(lifestage) %>%
    summarize(n = sum(n)) %>%
    pivot_wider(names_from = lifestage, values_from = n) %>%
    mutate(SAR = total_run/smolts, bay = new_surv, pop = "Coho")
}

modify_bay_coho(hab_base_coho$bay[1])

new_vals_coho <- map_dfr(seq(0.05, 0.5, 0.05), ~ modify_bay_coho(.x))

escapement <- data.frame(
  pop = c("Chinook", "Coho", "Steelhead"),
  n = c(3917, 45193, 2501),
  observed = "Median Esc.",
  SAR = c(NA,0.041,NA)) %>%
  filter(pop == "Coho")

ggplot(new_vals_coho) +
  geom_hline(aes(yintercept = n, color = observed), data = escapement)+
  geom_vline(
    aes(xintercept = SAR),
    data = escapement,
    color = "gray50", linetype = 2)+
  geom_line(aes(SAR, spawners)) +
  facet_wrap("pop", scales = "free")+
  scale_x_continuous(labels = scales::label_percent())+
  #geom_point(aes(SAR, spawners)) +
  cowplot::theme_minimal_grid()+
  labs(y = "Spawners", title = "Snohomish single-SAR")+
  theme(legend.title = element_blank(), legend.position = "bottom")

ggsave(sprintf("ignore/results/spawners_v_SAR_SNO_%s.png", Sys.Date()),
       width = 5, height =5)
