# calculate number of outmigrants for each population

coho <- hab_run("coho", "Current", "curr") %>%
  lcm_assign() %>%
  lcm_run(c("smolts", "ocean0")) %>%
  filter(year == 100) %>%
  mutate(
    species = "Coho",
    subgroup = "coho",
    timing = ifelse(lifestage == "smolts", "pre-delta", "post-delta")) %>%
  group_by(species, subgroup, timing) %>%
  summarize(n = sum(n))

fall_chinook <- hab_run("fall_chinook", "Current", "curr") %>%
  lcm_assign() %>%
  lcm_run(c(
    "fry_migrants",
    "sub_yr",
    "yearlings",
    "fry_migrants_bay",
    "sub_yr_bay",
    "yearlings_bay")) %>%
  filter(year == 100) %>%
  mutate(
    species = "Chinook",
    subgroup = case_when(
      grepl("fry", lifestage) ~ "fry",
      grepl("yearlings", lifestage) ~ "yearlings",
      TRUE ~ "12-week"),
    timing = ifelse(grepl("bay", lifestage), "post-delta", "pre-delta")) %>%
  group_by(species, subgroup, timing) %>%
  summarize(n = sum(n))

steelhead <-
  lcm_assign_steelhead(
    hab_run("winter_steelhead", "Current", "curr"),
    hab_run("summer_steelhead", "Current", "curr")) %>%
  lcm_run("all") %>%
  filter(
    year == 100,
    lifestage %in% c("smolts_winter", "smolts_summer", "fry_migrants_bay", "sub_yr_bay") |
      grepl("_1_ocean_", lifestage)) %>%
  mutate(
    species = "Steelhead",
    subgroup = ifelse(grepl("winter", lifestage), "winter", "summer"),
    timing = ifelse(grepl("smolts", lifestage), "pre-delta", "post-delta")) %>%
  group_by(species, subgroup, timing) %>%
  summarize(n = sum(n))

all_fish <- bind_rows(coho, fall_chinook, steelhead) %>%
  mutate(n = floor(n)) %>%
  pivot_wider(names_from = timing, values_from = n) %>%
  mutate(basin = "Snohomish") %>%
  relocate("post-delta", .after = "pre-delta")%>%
  relocate("basin")

write.csv(
  all_fish,
  sprintf("~/lcm_outputs/SNO_smolts_%s.csv", Sys.Date()),
  row.names = F)
